@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '0.009';
+$Playwright::VERSION = '0.010';
 use strict;
 use warnings;
 
@@ -62,7 +62,7 @@ sub _check_node {
 
         # Attempt to install deps automatically.
         confess(
-            "Production install of node dependencies must be done manually by nonroot users. Run the following:\n\n pushd '$curdir' && sudo npm i yargs express playwright uuid; popd\n\n"
+            "Production install of node dependencies must be done manually by nonroot users. Run the following:\n\n pushd '$curdir' && sudo npm i yargs express playwright uuid; popd\n\nIf this doesn't resolve the issue, export NODE_PATH='$curdir/node_modules'."
         ) if $global_install;
 
         my $err = capture_stderr { qx{npm i} };
@@ -304,7 +304,7 @@ sub _start_server ( $port, $timeout, $debug ) {
         return $pid;
     }
 
-    exec( $node_bin, $server_bin, "-p", $port, $debug );
+    exec( $node_bin, $server_bin, "--port", $port, $debug );
 }
 
 1;
@@ -321,7 +321,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -367,6 +367,14 @@ All the classes mentioned there will correspond to a subclass of the Playwright
 
 See example.pl for a more thoroughly fleshed-out display on how to use this module.
 
+=head3 Getting Started
+
+When using the playwright module for the first time, you may be told to install dependencies.
+It should provide you with instructions which will get you working right away.
+
+However, depending on your node installation this may not work due to dependencies for node.js not being in the expected location.
+To fix this, you will need to update your NODE_PATH environment variable to point to the correct location.
+
 =head3 Questions?
 
 Feel free to join the Playwright slack server, as there is a dedicated #playwright-perl channel which I, the module author, await your requests in.
